import { world, system } from "@minecraft/server";

function parseTypeId(typeId) {
    const parts = typeId.split(":");
    return parts.length > 1 ? parts[1] : parts[0];
}

function formatName(typeId) {
    return parseTypeId(typeId)
        .split("_")
        .map(word => word.charAt(0).toUpperCase() + word.slice(1))
        .join(" ");
}

function getRecommendedTool(blockTypeId) {
    const blockKey = parseTypeId(blockTypeId).toLowerCase(); // Normalize block type ID and make it lowercase

    // Determine the tool type based on keywords
    if (blockKey.includes("log") || blockKey.includes("wood") || blockKey.includes("planks")) {
        return "Axe";
    } else if (blockKey.includes("stone") || blockKey.includes("ore")) {
        return "Pickaxe";
    } else if (blockKey.includes("leaves")) {
        return "Shears";
    } else if (blockKey.includes("sand") || blockKey.includes("dirt") || blockKey.includes("gravel")) {
        return "Shovel";
    } else {
        return "Hand/None"; // Default tool for unmapped blocks
    }
}

function displayBlockInfo(player, block) {
    if (!block) return;

    const blockName = `§e${formatName(block.typeId)}`;
    const recommendedTool = getRecommendedTool(block.typeId);
    const displayText = `${blockName} §7(Tool: §a${recommendedTool}§7)`;
    player.onScreenDisplay.setActionBar({ text: displayText });
}

function displayEntityInfo(player, entity) {
    if (!entity) return;

    const entityName = `§e${formatName(entity.typeId)}`;
    const healthComponent = entity.getComponent("health");
    let healthInfo = "";

    if (healthComponent) {
        const currentHealth = healthComponent.currentValue;
        const maxHealth = healthComponent.effectiveMax;
        healthInfo = ` §4(${currentHealth}/${maxHealth} HP)`;
    }

    const displayText = `${entityName}${healthInfo}`;
    player.onScreenDisplay.setActionBar({ text: displayText });
}

system.runInterval(() => {
    for (const player of world.getAllPlayers()) {
        if (!player.isSneaking) {
            player.onScreenDisplay.setActionBar({ text: "" });
            continue; // Skip if the player is not crouching
        }

        const viewEntity = player.getEntitiesFromViewDirection({ maxDistance: 6 })[0];
        if (viewEntity) {
            displayEntityInfo(player, viewEntity.entity);
            continue;
        }

        const viewBlock = player.getBlockFromViewDirection({
            maxDistance: 6,
            includeLiquidBlocks: true,
            includePassableBlocks: true,
        });

        if (viewBlock) {
            displayBlockInfo(player, viewBlock.block);
        } else {
            player.onScreenDisplay.setActionBar({ text: "" });
        }
    }
}, 5);
